@@ -21,9 +21,11 @@ def square(image):
 @click.command()
 @click.option('--gray', '-g', help="Generate gray image.",
               is_flag=True)
+@click.option('--ico', '-i', help="Save as .ico file.",
+              is_flag=True)
 @click.argument("FILENAME")
 @click.argument("SIZE", nargs=-1)
-def cli(filename, size, gray):
+def cli(filename, size, gray, ico):
     if not size:
         size = (16, 32, 48, 128)
     else:
@@ -32,9 +34,10 @@ def cli(filename, size, gray):
     src_image = Image.open(filename, "r")
     src_image = square(src_image)
 
+    ext = "ico" if ico else "png"
     for size in size:
         icon = src_image.resize((size, size), Image.LANCZOS)
-        icon.save("icon{size}.png".format(size=size))
+        icon.save(f"icon{size}.{ext}".format(size=size))
         if gray:
             grayscale_icon = ImageOps.grayscale(icon)
             grayscale_icon.save("icon{size}-disable.png".format(size=size))
